# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.inbox_forwarder_controller_api import InboxForwarderControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestInboxForwarderControllerApi(unittest.TestCase):
    """InboxForwarderControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.inbox_forwarder_controller_api.InboxForwarderControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_new_inbox_forwarder(self):
        """Test case for create_new_inbox_forwarder

        Create an inbox forwarder  # noqa: E501
        """
        pass

    def test_delete_inbox_forwarder(self):
        """Test case for delete_inbox_forwarder

        Delete an inbox forwarder  # noqa: E501
        """
        pass

    def test_delete_inbox_forwarders(self):
        """Test case for delete_inbox_forwarders

        Delete inbox forwarders  # noqa: E501
        """
        pass

    def test_get_inbox_forwarder(self):
        """Test case for get_inbox_forwarder

        Get an inbox forwarder  # noqa: E501
        """
        pass

    def test_get_inbox_forwarders(self):
        """Test case for get_inbox_forwarders

        List inbox forwarders  # noqa: E501
        """
        pass

    def test_test_inbox_forwarder(self):
        """Test case for test_inbox_forwarder

        Test an inbox forwarder  # noqa: E501
        """
        pass

    def test_test_inbox_forwarders_for_inbox(self):
        """Test case for test_inbox_forwarders_for_inbox

        Test inbox forwarders for inbox  # noqa: E501
        """
        pass

    def test_test_new_inbox_forwarder(self):
        """Test case for test_new_inbox_forwarder

        Test new inbox forwarder  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
